<?php

namespace Litecms\KycSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\KycSetting\Http\Requests\KycSettingsRequest;
use Litecms\KycSetting\Interfaces\KycSettingsRepositoryInterface;
use Litecms\KycSetting\Models\KycSettings;

/**
 * Resource controller class for kyc_settings.
 */
class KycSettingsResourceController extends BaseController
{

    /**
     * Initialize kyc_settings resource controller.
     *
     * @param type KycSettingsRepositoryInterface $kyc_settings
     *
     * @return null
     */
    public function __construct(KycSettingsRepositoryInterface $kyc_settings)
    {
        parent::__construct();
        $this->repository = $kyc_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KycSetting\Repositories\Criteria\KycSettingsResourceCriteria::class);
    }

    /**
     * Display a list of kyc_settings.
     *
     * @return Response
     */
    public function index(KycSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\KycSetting\Repositories\Presenter\KycSettingsPresenter::class)
                ->$function();
        }

        $kyc_settings = $this->repository->paginate();

        return $this->response->title(trans('kyc_setting::kyc_settings.names'))
            ->view('kyc_setting::kyc_settings.index', true)
            ->data(compact('kyc_settings'))
            ->output();
    }

    /**
     * Display kyc_settings.
     *
     * @param Request $request
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function show(KycSettingsRequest $request, KycSettings $kyc_settings)
    {

        if ($kyc_settings->exists) {
            $view = 'kyc_setting::kyc_settings.show';
        } else {
            $view = 'kyc_setting::kyc_settings.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('kyc_setting::kyc_settings.name'))
            ->data(compact('kyc_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new kyc_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(KycSettingsRequest $request)
    {

        $kyc_settings = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('kyc_setting::kyc_settings.name')) 
            ->view('kyc_setting::kyc_settings.create', true) 
            ->data(compact('kyc_settings'))
            ->output();
    }

    /**
     * Create new kyc_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KycSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $kyc_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('kyc_setting::kyc_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kyc_setting/kyc_settings/' . $kyc_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/kyc_setting/kyc_settings'))
                ->redirect();
        }

    }

    /**
     * Show kyc_settings for editing.
     *
     * @param Request $request
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function edit(KycSettingsRequest $request, KycSettings $kyc_settings)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('kyc_setting::kyc_settings.name'))
            ->view('kyc_setting::kyc_settings.edit', true)
            ->data(compact('kyc_settings'))
            ->output();
    }

    /**
     * Update the kyc_settings.
     *
     * @param Request $request
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function update(KycSettingsRequest $request, KycSettings $kyc_settings)
    {
        try {
            $attributes = $request->all();

            $kyc_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('kyc_setting::kyc_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('kyc_setting/kyc_settings/' . $kyc_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kyc_setting/kyc_settings/' . $kyc_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the kyc_settings.
     *
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function destroy(KycSettingsRequest $request, KycSettings $kyc_settings)
    {
        try {

            $kyc_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kyc_setting::kyc_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('kyc_setting/kyc_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kyc_setting/kyc_settings/' . $kyc_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple kyc_settings.
     *
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function delete(KycSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('kyc_setting::kyc_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('kyc_setting/kyc_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kyc_setting/kyc_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted kyc_settings.
     *
     * @param Model   $kyc_settings
     *
     * @return Response
     */
    public function restore(KycSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('kyc_setting::kyc_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/kyc_setting/kyc_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/kyc_setting/kyc_settings/'))
                ->redirect();
        }

    }

}
